@@ -23,40 +23,14 @@
  *   James Willcox <jwillcox@cs.indiana.edu>
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include <libgnome/gnome-i18n.h>
-
 #include <errno.h>
-#include <unistd.h>
-#include <string.h>
-#include <libgnomevfs/gnome-vfs.h>
-
-#include <gedit-plugin.h>
-#include <gedit-file.h>
-#include <gedit-debug.h>
-#include <gedit-menus.h>
-#include <gedit-utils.h>
+#include "gedit-plugin.h"
+#include "gedit-file.h"
+#include "gedit-debug.h"
 
 #define GEDIT_CVSCHANGELOG_PLUGIN_PATH_STRING_SIZE 1
 
-/* AFAIK, all cvs commit messages start with this */
-#define GEDIT_CVSCHANGELOG_START_HEADER "\nCVS: ------"
-
-
-#define MENU_ITEM_LABEL		N_("Open CVS Chan_geLogs")
-#define MENU_ITEM_PATH		"/menu/File/FileOps_2/"
-#define MENU_ITEM_NAME		"CVSChangeLog"	
-#define MENU_ITEM_TIP		N_("Searches for ChangeLogs in the current document and opens them")
-
-G_MODULE_EXPORT GeditPluginState update_ui (GeditPlugin *plugin, BonoboWindow *window);
-G_MODULE_EXPORT GeditPluginState activate (GeditPlugin *pd);
-G_MODULE_EXPORT GeditPluginState deactivate (GeditPlugin *pd);
-G_MODULE_EXPORT GeditPluginState init (GeditPlugin *pd);
-
-
 static gchar *
 get_cwd (void)
 {
@@ -80,33 +54,38 @@ get_cwd (void)
 static gint
 is_changelog (const gchar * path)
 {
-	gboolean ret = FALSE;
-	gchar *base;
+	int index = strlen (path) - 9;
 
-	base = g_path_get_basename (path);
+	if (index >= 0) {
+		if (!strcasecmp (&path[index], "changelog"))
+			return TRUE;
+	}
 
-	if (g_utf8_caselessnmatch (base, "changelog",
-				   strlen (base), strlen ("changelog")))
-		ret = TRUE;
-
-	g_free (base);
-
-	return ret;
+	return FALSE;
 }
 
-
-static GList *
-get_changelogs (const gchar *buf)
+static void
+cvs_changelogs_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
 {
-	GList *list=NULL;
+	GeditView *view = gedit_get_active_view ();
+	GeditDocument *doc;
+	gchar *buf;
 	guchar *filename;
 	gchar *current_dir;
-	gchar *uri;
-	gchar *local_path;
+	gchar *full_uri;
 	gchar **split_file;
 	gchar **split_line;
 	gint i, j;
 
+
+	gedit_debug (DEBUG_PLUGINS, "");
+
+	g_return_if_fail (view);
+
+	doc = gedit_view_get_document (view);
+
+	buf = gedit_document_get_buffer (doc);
+
 	/* split the file up line by line */
 	split_file = g_strsplit (buf, "\n", 0);
 
@@ -125,15 +104,15 @@ get_changelogs (const gchar *buf)
 				
 				if(!current_dir)
 					continue;
+				
+				full_uri = g_strdup_printf("file:///%s/%s", current_dir, filename);
 
-				local_path = g_strdup_printf("%s/%s", current_dir, filename);
-
-				uri = gnome_vfs_get_uri_from_local_path (local_path);
-				list = g_list_append (list, uri);
-
+				/* open the changelog */
+				gedit_file_open_single_uri (full_uri);
+				
 				/* cleanup. */
+				g_free(full_uri);
 				g_free(current_dir);
-				g_free (local_path);
 			}
 		}
 
@@ -141,113 +120,60 @@ get_changelogs (const gchar *buf)
 	}
 
 	g_strfreev (split_file);
-
-	return list;
 }
 
-static gboolean
-is_commit_message (const char *buf)
-{
-	GList *list = NULL;
-
-	if (!strncmp (buf, GEDIT_CVSCHANGELOG_START_HEADER,
-		      strlen (GEDIT_CVSCHANGELOG_START_HEADER))) {
-		list = get_changelogs (buf);
-		if (list) {
-			g_list_foreach (list, (GFunc)g_free, NULL);
-			g_list_free (list);
-			return TRUE;
-		}
-	}
-	
-	return FALSE;
-}
-
-static void
-cvs_changelogs_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
-{
-	GeditView *view = gedit_get_active_view ();
-	GeditDocument *doc;
-	gchar *buf;
-	GList *list;
-	GList *tmp;
-
-	gedit_debug (DEBUG_PLUGINS, "");
-
-	g_return_if_fail (view);
-
-	doc = gedit_view_get_document (view);
-
-	buf = gedit_document_get_chars (doc, 0, -1);
-
-	list = get_changelogs (buf);
-
-	tmp = list;
-	while (tmp) {
-		gedit_file_open_single_uri ((gchar *)tmp->data);
-
-		tmp = tmp->next;
-	}
-
-	g_list_foreach (list, (GFunc)g_free, NULL);
-	g_list_free (list);
-}
-
-
 G_MODULE_EXPORT GeditPluginState
-update_ui (GeditPlugin *plugin, BonoboWindow *window)
+destroy (GeditPlugin *plugin)
 {
-	BonoboUIComponent *uic;
-	GeditDocument *doc;
-	gchar *buf;
-	
-	gedit_debug (DEBUG_PLUGINS, "");	
-	g_return_val_if_fail (window != NULL, PLUGIN_ERROR);
-
-	uic = gedit_get_ui_component_from_window (window);
-
-	doc = gedit_get_active_document ();
-
-	if (doc != NULL) {	 	
-		buf = gedit_document_get_chars (doc, 0, -1);
-
-		if (is_commit_message (buf))
-			gedit_menus_set_verb_sensitive (uic,
-							"/commands/" MENU_ITEM_NAME, TRUE);
-		else
-			gedit_menus_set_verb_sensitive (uic,
-							"/commands/" MENU_ITEM_NAME, FALSE);
-		g_free (buf);
-	}
-	else {
-		gedit_menus_set_verb_sensitive (uic, "/commands/" MENU_ITEM_NAME, FALSE);
-	}
-
-	return PLUGIN_OK;
+	gedit_debug (DEBUG_PLUGINS, "");
 }
 
 G_MODULE_EXPORT GeditPluginState
 activate (GeditPlugin *pd)
 {
-	GList *top_windows;
-        gedit_debug (DEBUG_PLUGINS, "");
+	GList* top_windows;
+	
+	gedit_debug (DEBUG_PLUGINS, "");
 
-        top_windows = gedit_get_top_windows ();
-        g_return_val_if_fail (top_windows != NULL, PLUGIN_ERROR);
+	top_windows = gedit_get_top_windows ();
+	g_return_if_fail (top_windows != NULL);
+       
+	while (top_windows)
+	{
+		BonoboUIComponent* ui_component;
+		gchar *item_path;
+		ui_component = gedit_get_ui_component_from_window (
+					BONOBO_WINDOW (top_windows->data));
+		
+		item_path = g_strdup ("/menu/File/FileOps/CVSChangelog");
 
-        while (top_windows)
-        {
-		gedit_menus_add_menu_item (BONOBO_WINDOW (top_windows->data),
-				     MENU_ITEM_PATH, MENU_ITEM_NAME,
-				     MENU_ITEM_LABEL, MENU_ITEM_TIP,
-				     GTK_STOCK_OPEN, cvs_changelogs_cb);
+		if (!bonobo_ui_component_path_exists (ui_component, item_path, NULL))
+		{
+			gchar *xml;
+					
+			xml = g_strdup ("<menuitem name=\"CVSChangelog\" verb=\"\""
+					" _label=\"Open _CVS Changelogs\""
+				        " _tip=\"Opens changelogs from CVS commit logs\" hidden=\"0\" />");
 
-                pd->update_ui (pd, BONOBO_WINDOW (top_windows->data));
+			bonobo_ui_component_set_translate (ui_component, 
+					"/menu/File/FileOps/", xml, NULL);
 
-                top_windows = g_list_next (top_windows);
-        }
+			bonobo_ui_component_set_translate (ui_component, 
+					"/commands/", "<cmd name = \"CVSChangelog\" />", NULL);
 
-        return PLUGIN_OK;
+			bonobo_ui_component_add_verb (ui_component, 
+					"CVSChangelog", cvs_changelogs_cb, 
+					      NULL); 
+
+			g_free (xml);
+		}
+		
+		g_free (item_path);
+		
+		top_windows = g_list_next (top_windows);
+	}
+
+	return PLUGIN_OK;
 }
 
 
@@ -255,9 +181,32 @@ activate (GeditPlugin *pd)
 G_MODULE_EXPORT GeditPluginState
 deactivate (GeditPlugin *plugin)
 {
-	gedit_menus_remove_menu_item_all (MENU_ITEM_PATH, MENU_ITEM_NAME);
+	GList* top_windows;
+	
+	gedit_debug (DEBUG_PLUGINS, "");
 
-	return PLUGIN_OK;
+	top_windows = gedit_get_top_windows ();
+	g_return_if_fail (top_windows != NULL);
+       
+	while (top_windows)
+	{
+		BonoboUIComponent* ui_component;
+		gchar *item_path;
+		ui_component = gedit_get_ui_component_from_window (
+					BONOBO_WINDOW (top_windows->data));
+		
+		item_path = g_strdup ("/menu/File/FileOps/CVSChangelog");
+
+		if (bonobo_ui_component_path_exists (ui_component, item_path, NULL))
+		{
+			bonobo_ui_component_rm (ui_component, item_path, NULL);
+			bonobo_ui_component_rm (ui_component, "/commands/CVSChangelog", NULL);
+		}
+		
+		g_free (item_path);
+		
+		top_windows = g_list_next (top_windows);
+	}
 }
 
 G_MODULE_EXPORT GeditPluginState
@@ -266,6 +215,7 @@ init (GeditPlugin* plugin)
 	/* initialize */
 	gedit_debug (DEBUG_PLUGINS, "");
 
+	plugin->destroy = destroy;
 	plugin->name = _("CVS ChangeLog");
 	plugin->desc = _("A plugin that opens ChangeLogs found in CVS commit messages.");
 	plugin->author = "James Willcox <jwillcox@cs.indiana.edu>";
